@@ -11,10 +11,14 @@ from collections import Counter
 from PIL import Image
 from transformers import DetrFeatureExtractor, DetrForSegmentation, \
     SegformerFeatureExtractor, SegformerForImageClassification
-from social_net_img_classifier.settings import COCO_CATEGORIES, FEATURES, MODEL_IMG_DIR, MODEL_STTM_DIR, MODEL_TEXT_DIR, MODEL_TEXT_BERT_DIR, TOP_OBJECTS
+import openai
+from social_net_img_classifier.settings import COCO_CATEGORIES, FEATURES, MODEL_IMG_DIR, MODEL_STTM_DIR, MODEL_TEXT_DIR, MODEL_TEXT_BERT_DIR, \
+    OPENAI_API_KEY, PROMPT_DIR, TOP_OBJECTS
 from social_net_img_classifier.training import TrainClassModel, TrainClfTextModel
 from social_net_img_classifier.aws_utils import AwsS3
 
+PROMPT = AwsS3().read_file(PROMPT_DIR).decode("utf-8").replace("\r\n", "\n")
+
 
 class ClassifyImg:
     """
@@ -201,3 +205,66 @@ class GetFeaturesImg:
             print(f"colors: problemas detectando colores.")
             dict_colors = {}
         return dict_colors
+
+
+class OpenAI:
+    """
+    :Date: 2022-11-18
+    :Version: 0.1
+    :Authors: Juan David Torres - Whale & Jaguar Consultants S.A.S.
+    :Description: HERRAMIENTAS AUXILIARES PARA CLASIFICACIÓN DE TEXTO DESDE OPENAI
+    """
+    @staticmethod
+    def filter_content(text):
+        """
+        This function analyze the text and indicates
+         if text is hateful, prejuice or profane
+        :param text: type str, text to analyze
+        :return: text: type str, text clasification
+        """
+        openai.api_key = OPENAI_API_KEY
+        response = openai.Completion.create(
+            model="content-filter-alpha",
+            prompt="<|endoftext|>" + text + "\n--\nLabel:",
+            temperature=0,
+            max_tokens=1,
+            top_p=0,
+            logprobs=10
+        )
+        return response.choices[0].text
+
+    @staticmethod
+    def clf_moment(text, engine="text-curie-001"):
+        """
+            This function receives a text and a model type from gpt3 and
+            returns classifies the text if it is a consumption moment or not.
+
+        Parameters
+        ----------
+        text : TYPE str
+            DESCRIPTION. text to classify
+        engine : TYPE str
+            DESCRIPTION. model gpt-3
+            "text-curie-001" or "text-davinci-002"
+
+        Returns
+        -------
+        output : TYPE
+            DESCRIPTION.
+        """
+        openai.api_key = OPENAI_API_KEY
+        response = openai.Completion.create(
+            engine=engine,
+            prompt=f"{PROMPT}\ntext:{text}<EOS>\nclasification:",
+            temperature=0.7,
+            max_tokens=256,
+            echo=True,
+            logprobs=0,
+            presence_penalty=0.0,
+            frequency_penalty=0.0,
+            best_of=1,
+        )
+        output = response["choices"][0]["text"][-1]
+        if output in ["0", "1"]:
+            return int(output)
+        return 0
