@@ -19,12 +19,12 @@ from multiprocessing import Process, Manager, cpu_count
 from wj_social_net_queries.core.instagram import Instagram
 from wj_social_net_queries.core.twitter import Twitter
 from social_net_img_classifier.aws_utils import AwsS3
-from social_net_img_classifier.classify import ClassifyImg, ClassifySTTM, ClassifyText
+from social_net_img_classifier.classify import ClassifyImg, ClassifySTTM, ClassifyText, OpenAI
 from social_net_img_classifier.db_tools import MySQLtools
 from social_net_img_classifier.utils import GenderByText, NlpUtils, CalcUtils, Location
 from social_net_img_classifier.settings import AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY, BRANDS, BUCKET_NAME, BUSINESS_NAME_WORDS, COUNTRIES, \
     DATE_COL, DAYS_LIMIT, GREETINGS, IG_BUSINESS_CATEGORY, IG_CATEGORY, IMG_DB_FIELDS, IG_TOKEN, LANGUAGES, LOCATIONS, \
-    MAX_TWEETS_PER_TERM, TARGET, TEMPLATES, TERMS, TW_CONN
+    MAX_TWEETS_PER_TERM, OPENAI_CLF, TARGET, TEMPLATES_DM_DIR, TEMPLATES_RP_DIR, TERMS, TW_CONN
 
 KEYS = {
     "images": ["filename"],
@@ -36,11 +36,14 @@ KEYS = {
 TW_TERMS = [x.lower() for x in TERMS["twitter"] + BRANDS["twitter"]]
 IG_TERMS = TERMS["instagram"]
 
+TEMPLATES_DM = list(pd.read_json(AwsS3().read_file(TEMPLATES_DM_DIR))["text"])
+TEMPLATES_RP = pd.read_json(AwsS3().read_file(TEMPLATES_RP_DIR))
+
 
 class MainETL:
     """
-    :Date: 2022-11-10
-    :Version: 1.4
+    :Date: 2022-12-05
+    :Version: 1.7
     :Author: Joan Felipe Mendoza - Whale & Jaguar Consultants S.A.S.
     :Description: PIPELINE PRINCIPAL
     """
@@ -103,7 +106,8 @@ class MainETL:
             # Almacenar datos en MySQL
             _ = MySQLtools(table="tweets").update_table(tweets_data, KEYS["tweets"], batch=batch)
             # Enviar mensajes directos a usuarios
-            print(Responding().twitter_dm(contacts))
+            responses = Responding().twitter(contacts)
+            _ = MySQLtools(table="report_tw").update_table(responses, KEYS["report_tw"], batch=batch)
             print(f"Tiempo de proceso: {datetime.now() - start}")
 
     def process_batch_tw(self, tweets_data):
@@ -130,7 +134,7 @@ class MainETL:
             # Calcular lista de usuarios a contactar
             if data.shape[0]:
                 true_cases = data[(data[TARGET] == 1) & (data["gender"].isin(["M", "F"])) & (data["verified"] == 0)]
-                contacts = true_cases[["screen_name", "twitter_id", "user_name"]].drop_duplicates().to_dict("records")
+                contacts = true_cases[["screen_name", "twitter_id", "user_name", "tweet_id", "sttm_group"]].to_dict("records")
             data_0 = tweets_data[~tweets_data["country_iso2"].isin(COUNTRIES)]
             data_0[TARGET] = [-1] * len(data_0)  # Inicializar como No predecido
             data = pd.concat([data, data_0], axis=0).reset_index(drop=True)
@@ -178,7 +182,14 @@ class MainETL:
             df["color_img"] = color_list
             df["img_url"] = img_list
             df["target_img"] = target_list
-            df[TARGET] = df[["target_img", "target_text"]].values.max(axis=1)
+            target_list = []
+            for _, row in df.iterrows():
+                target = 0
+                if max(row["target_img"], row["target_text"]) == 1:  # Si es un caso positivo...
+                    if OpenAI().filter_content(str(row["text"])) == "0":  # Si el texto no es inapropiado...
+                        target = OpenAI().clf_moment(row["text"]) if OPENAI_CLF else 1
+                target_list.append(target)
+            df[TARGET] = target_list
             end = datetime.now()
             print(f"*Image Clf total time* {end - start}\n"
                   f"*Images* {l}\n"
@@ -572,6 +583,12 @@ class StatsETL:
 
 
 class Responding:
+    """
+    :Date: 2022-11-22
+    :Version: 0.2
+    :Author: Joan Felipe Mendoza - Whale & Jaguar Consultants S.A.S.
+    :Description: ENVIAR MENSAJES A USUARIOS
+    """
     def __init__(self):
         # Inicializar instancia
         self.instance = Twitter(
@@ -582,10 +599,9 @@ class Responding:
             )
 
     def twitter_dm(self, contacts):
-        users_sent = []
+        data = pd.DataFrame()
         if contacts:
             # Enviar mensajes por DM
-            data = []
             for contact in contacts:
                 if contact["screen_name"] not in BRANDS["twitter"]:
                     if contact["user_name"]:
@@ -597,7 +613,7 @@ class Responding:
                             greeting = f"¡{random.choice(GREETINGS)}!"
                     else:
                         greeting = f"¡{random.choice(GREETINGS)}!"
-                    text = f"{greeting} {random.choice(TEMPLATES)}"
+                    text = f"{greeting} {random.choice(TEMPLATES_DM)}"
                     sent = self.instance.send_direct_message(text=text, twitter_id=str(contact["twitter_id"]))
                     data.append(
                         {**contact,
@@ -607,7 +623,72 @@ class Responding:
                          "sent": sent,
                          }
                     )
-            # Cargar a base de datos
+        return data
+
+    def twitter_response(self, tweets_info):
+        data = pd.DataFrame()
+        if tweets_info:
+            # Responder tweets
+            for tweet in tweets_info:
+                if tweet["screen_name"] not in BRANDS["twitter"]:
+                    text = f"Mensaje de prueba"
+                    status_id = tweet["tweet_id"]
+                    user_name = f'@{tweet["screen_name"]}'
+                    sent = self.instance.write_comment(status=text, in_reply_status_id=status_id, user_name=user_name)
+                    data.append(
+                        {**tweet,
+                         "id": str(uuid.uuid4()),
+                         "datestamp": datetime.now().strftime("%Y-%m-%d %H:%M:%S"),
+                         "message": text,
+                         "sent": sent,
+                         }
+                    )
             data = pd.DataFrame(data)
-            users_sent = list(data[data["sent"] == 1]["screen_name"])
-        return [users_sent, data]
+        return data
+
+    def twitter(self, tweets_info, dm=True, response=True):
+        responses = pd.DataFrame()
+        if tweets_info:
+            data = []
+            for row in tweets_info:
+                if row["screen_name"] not in BRANDS["twitter"]:
+                    text, dm_sent, response_sent = None, 0, 0
+                    # 1. Enviar mensajes por DM
+                    if dm:
+                        if row["user_name"]:
+                            name = NlpUtils.norm_text(row["user_name"], preserve_es_char=True)
+                            words = name.split()
+                            if words and len(words[0]) > 2:
+                                greeting = f"¡{random.choice(GREETINGS)} {words[0]}!"
+                            else:
+                                greeting = f"¡{random.choice(GREETINGS)}!"
+                        else:
+                            greeting = f"¡{random.choice(GREETINGS)}!"
+                        text = f"{greeting} {random.choice(TEMPLATES_DM)}"
+                        dm_sent = self.instance.send_direct_message(text=text, twitter_id=str(row["twitter_id"]))
+                    # 2. Responder tweets en caso de que no se haya enviado DM
+                    if response and dm_sent == 0:
+                        mssg = list(TEMPLATES_RP[TEMPLATES_RP["sttm_group"] == row["sttm_group"]]["text"])
+                        if len(mssg):
+                            text = random.choice(mssg)
+                            response_sent = self.instance.write_comment(
+                                status=text,
+                                in_reply_status_id=row["tweet_id"],
+                                user_name=f'@{row["screen_name"]}'
+                            )
+                    data.append(
+                        {
+                            "twitter_id": row["twitter_id"],
+                            "screen_name": row["screen_name"],
+                            "user_name": row["user_name"],
+                            "id": str(uuid.uuid4()),
+                            "datestamp": datetime.now().strftime("%Y-%m-%d %H:%M:%S"),
+                            "message": text,
+                            "sent": True if max(dm_sent, response_sent) else False,
+                            "dm_sent": dm_sent,
+                            "response_sent": True if response_sent else False,
+                            "tweet_id": row["tweet_id"],
+                        }
+                    )
+            responses = pd.DataFrame(data)
+        return responses
